package cn.qqck.kotlin.tools

object Android {
    data class Info(
        /**
         * 手机正式名称、手机品牌
         * - ro.product.name
         * - cmi
         */
        val name: String,
        /**
         * 手机品牌
         * - ro.product.brand
         * - Xiaomi
         */
        val brand: String,
        /**
         * 主板、cpu代号？
         * - ro.product.board
         * - kalama
         */
        val board: String,
        /**
         * 手机型号
         * - ro.product.model
         * - M2001J1E
         */
        val model: String,
        /**
         * 设备名
         * - ro.product.device
         * - cmi
         */
        val device: String,
        /**
         * 制造商
         * - ro.product.manufacturer
         * - Xiaomi
         */
        val manufacturer: String,
        /**
         * 硬件名
         * - ro.hardware
         * - qcom
         */
        val hardware: String,
        /**
         * 系统版本
         * - Build.VERSION.RELEASE
         * - 10、11
         */
        val version: String,
        /**
         * 设备首次使用的 API 级别（Android 版本）
         * - ro.product.firstApiLevel
         * - Android(29、32、33)
         */
        val firstApiLevel: String,
        /**
         * GPU 供应商
         * - ro.gpu.vendor
         * - Qualcomm
         */
        val gpu_vendor: String,
        /**
         * GPU 型号
         * - ro.gpu.renderer
         * - Adreno (TM) 650
         */
        val gpu_renderer: String,
        /**
         * 运行内存
         * - 8、12
         */
        val ram: Int,
        /**
         * 手机平台信息
         * - Linux aarch64、Linux armv8l
         */
        val platfrom: String,
    )

    private val array = arrayOf(
        // Info(
        //     "cmi", "Xiaomi", "lahaina", "M2001J1E", "cmi", "Xiaomi", "qcom", "10", "29",
        //     "Qualcomm", "Adreno (TM) 650", 8, "Linux aarch64",
        // ),
        // Info(
        //     "cmi", "Xiaomi", "lahaina", "M2001J1E", "cmi", "Xiaomi", "qcom", "10", "29",
        //     "Qualcomm", "Adreno (TM) 650", 12, "Linux aarch64",
        // ),
        // Info(
        //     "nuwa", "Xiaomi", "kalama", "2210132C", "nuwa", "Xiaomi", "qcom", "13", "33",
        //     "Qualcomm", "Adreno (TM) 740", 8, "Linux aarch64",
        // ),
        // Info(
        //     "nuwa", "Xiaomi", "kalama", "2210132C", "nuwa", "Xiaomi", "qcom", "13", "33",
        //     "Qualcomm", "Adreno (TM) 740", 12, "Linux aarch64",
        // ),
        // Info(
        //     "shennong", "Xiaomi", "kalama", "23116PN5BC", "shennong", "Xiaomi", "qcom", "13", "33",
        //     "Qualcomm", "Adreno (TM) 750", 12, "Linux aarch64",
        // ),
        // Info(
        //     "shennong", "Xiaomi", "kalama", "23116PN5BC", "shennong", "Xiaomi", "qcom", "13", "33",
        //     "Qualcomm", "Adreno (TM) 750", 16, "Linux aarch64",
        // ),
        // Info(
        //     "dm3q", "Samsung", "kalama", "SM-S9180", "dm3q", "Samsung", "qcom", "13", "33",
        //     "Qualcomm", "Adreno (TM) 750", 16, "Linux aarch64",
        // ),
        // Samsung
        Info(
            "SM-S901U", "Samsung", "exynos2100", "SM-S901U", "galaxyS22", "Samsung", "samsung", "12", "32",
            "Samsung", "ARM Mali-G78 MP14", 8, "Linux aarch64"
        ),
        Info(
            "SM-S908U", "Samsung", "snapdragon8Gen1", "SM-S908U", "galaxyS22Ultra", "Samsung", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        // OnePlus
        Info(
            "NE2211", "OnePlus", "snapdragon8Gen1", "NE2211", "oneplus10Pro", "OnePlus", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        Info(
            "PHP110", "OnePlus", "snapdragon8Gen2", "PHP110", "oneplus11", "OnePlus", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),

        // Google Pixel
        Info(
            "Pixel 6", "Google", "gs101", "GF5KQW", "oriole", "Google", "google", "12", "32",
            "Google", "Mali-G78 MP20", 8, "Linux aarch64"
        ),
        Info(
            "Pixel 7 Pro", "Google", "gs201", "GVU6C", "cheetah", "Google", "google", "13", "33",
            "Google", "Mali-G710 MC10", 12, "Linux aarch64"
        ),
        // Oppo
        Info(
            "PEEM00", "Oppo", "snapdragon888", "PEEM00", "findX3Pro", "Oppo", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 660", 12, "Linux aarch64"
        ),
        Info(
            "PGEM10", "Oppo", "dimensity9000", "PGEM10", "findX5Pro", "Oppo", "mtk", "12", "32",
            "MediaTek", "Mali-G710 MC10", 12, "Linux aarch64"
        ),

        // Vivo
        Info(
            "V2145A", "Vivo", "snapdragon8Gen1", "V2145A", "vivoX80Pro", "Vivo", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        Info(
            "V2254A", "Vivo", "snapdragon8Gen2", "V2254A", "vivoX90Pro+", "Vivo", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 12, "Linux aarch64"
        ),
        // Realme
        Info(
            "RMX3301", "Realme", "snapdragon8Gen1", "RMX3301", "realmeGT2Pro", "Realme", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        Info(
            "RMX3740", "Realme", "dimensity8100", "RMX3740", "realmeGTNeo3", "Realme", "mtk", "12", "32",
            "MediaTek", "Mali-G610 MC6", 8, "Linux aarch64"
        ),
        // Honor (荣耀)
        Info(
            "ANA-AN00", "Honor", "kirin9000", "ANA-AN00", "honorMagic3Pro", "Honor", "kirin", "11", "30",
            "HiSilicon", "Mali-G78 MP24", 8, "Linux aarch64"
        ),
        Info(
            "PCT-AL10", "Honor", "snapdragon8Gen1", "PCT-AL10", "honorMagic4Pro", "Honor", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        // RedMagic (红魔)
        Info(
            "NX669J", "RedMagic", "snapdragon888", "NX669J", "redMagic6Pro", "RedMagic", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 660", 16, "Linux aarch64"
        ),
        Info(
            "NX709S", "RedMagic", "snapdragon8Gen2", "NX709S", "redMagic8Pro", "RedMagic", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),
        // Meizu (魅族)
        Info(
            "M181Q", "Meizu", "snapdragon845", "M181Q", "meizu16th", "Meizu", "qcom", "9", "28",
            "Qualcomm", "Adreno (TM) 630", 8, "Linux aarch64"
        ),
        Info(
            "M2396", "Meizu", "snapdragon8Gen2", "M2396", "meizu20pro", "Meizu", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 12, "Linux aarch64"
        ),
        // ZTE (中兴)
        Info(
            "ZTE A2022P", "ZTE", "snapdragon888", "ZTE A2022P", "axon30Ultra", "ZTE", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 660", 12, "Linux aarch64"
        ),
        Info(
            "ZTE A2024", "ZTE", "snapdragon8Gen2", "ZTE A2024", "axon40 Ultra", "ZTE", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 12, "Linux aarch64"
        ),
        // Lenovo (联想)
        Info(
            "Lenovo Legion", "Lenovo", "snapdragon888", "L70081", "legionPhoneDuel2", "Lenovo", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 660", 16, "Linux aarch64"
        ),
        Info(
            "Lenovo Legion", "Lenovo", "snapdragon8Gen1", "L71061", "legionY90", "Lenovo", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 18, "Linux aarch64"
        ),

        // IQOO (Vivo旗下子品牌)
        Info(
            "V2149A", "IQOO", "snapdragon8Gen1", "V2149A", "iqoo9Pro", "IQOO", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        Info(
            "V2237A", "IQOO", "snapdragon8Gen2", "V2237A", "iqoo11Pro", "IQOO", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),

        // Black Shark (黑鲨，游戏手机)
        Info(
            "KALE-A0", "Black Shark", "snapdragon888", "KALE-A0", "blackShark4", "Black Shark", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 660", 12, "Linux aarch64"
        ),
        Info(
            "SHARK-PRC", "Black Shark", "snapdragon8Gen2", "SHARK-PRC", "blackShark5Pro", "Black Shark", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),

        // Nubia (努比亚，游戏与拍摄手机并重)
        Info(
            "NX703J", "Nubia", "snapdragon8Gen1", "NX703J", "nubiaZ40Pro", "Nubia", "qcom", "12", "32",
            "Qualcomm", "Adreno (TM) 730", 12, "Linux aarch64"
        ),
        Info(
            "NX711J", "Nubia", "snapdragon8Gen2", "NX711J", "nubiaZ50Ultra", "Nubia", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),

        // Coolpad (酷派)
        Info(
            "CP07", "Coolpad", "qualcommMSM8953", "CP07", "coolpadCool6", "Coolpad", "qcom", "10", "29",
            "Qualcomm", "Adreno (TM) 506", 4, "Linux aarch64"
        ),
        Info(
            "CP19", "Coolpad", "dimensity1200", "CP19", "coolpadCool20Pro", "Coolpad", "mtk", "12", "32",
            "MediaTek", "Mali-G77 MC9", 8, "Linux aarch64"
        ),

        // ASUS (华硕，常见于游戏手机的市场)
        Info(
            "ASUS_I005DA", "ASUS", "snapdragon888", "I005DA", "rogPhone5", "ASUS", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 660", 16, "Linux aarch64"
        ),
        Info(
            "AI2201", "ASUS", "snapdragon8Gen2", "AI2201", "rogPhone7Ultimate", "ASUS", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 18, "Linux aarch64"
        ),

        // OnePlus 的特殊型号
        Info(
            "IN2020", "OnePlus", "snapdragon865", "IN2020", "oneplus8Pro", "OnePlus", "qcom", "11", "30",
            "Qualcomm", "Adreno (TM) 650", 12, "Linux aarch64"
        ),
        Info(
            "CPH2451", "OnePlus", "snapdragon8Gen2", "CPH2451", "oneplusAcePro", "OnePlus", "qcom", "13", "33",
            "Qualcomm", "Adreno (TM) 740", 16, "Linux aarch64"
        ),

        // 荣耀 (新增光荣机型)
        Info(
            "FNE-AN00", "Honor", "kirin810", "FNE-AN00", "honor9X", "Honor", "kirin", "10", "29",
            "HiSilicon", "Mali-G52", 6, "Linux aarch64"
        ),
        Info(
            "LGE-AN10", "Honor", "dimensity8050", "LGE-AN10", "honor90Lite", "Honor", "mtk", "13", "33",
            "MediaTek", "Mali-G77 MC9", 12, "Linux aarch64"
        ),

        // 红米 (Redmi，低价高性能机型)
        Info(
            "21061119AG", "Redmi", "dimensity1200", "21061119AG", "redmiK40Gaming", "Redmi", "mtk", "11", "30",
            "MediaTek", "Mali-G77 MC9", 12, "Linux aarch64"
        ),
        Info(
            "23049RA19C", "Redmi", "dimensity9200", "23049RA19C", "redmiK60Ultra", "Redmi", "mtk", "13", "33",
            "MediaTek", "Immortalis-G715", 16, "Linux aarch64"
        ),
    )

    fun random(): Info = array.random()
}
