package cn.qqck.kotlin.tools

/**
 * 将当前字节数组编码为Base64格式的字符串表示。
 *
 * @return 转换后的Base64格式字符串。如果字节数组为空，则返回空字符串。
 */
fun ByteArray.base64(): String = java.util.Base64.getEncoder().encodeToString(this)
private val withoutPadding = java.util.Base64.getEncoder().withoutPadding()

/**
 * 将当前字节数组编码为Base64格式的字符串表示，并可以选择是否移除末尾的填充字符。
 *
 * @param without 指定是否移除Base64编码结果中末尾的填充字符。如果为true，则移除填充字符；否则保留。
 * @return 转换后的Base64格式字符串。如果字节数组为空，则返回空字符串。
 */
fun ByteArray.base64(without: Boolean): String = if (without) withoutPadding.encodeToString(this) else this.base64()

/**
 * 将字符串进行Base64解码并返回对应的字节数组。
 *
 * @return 解码后的字节数组。如果输入字符串的格式不正确，将可能引发异常。
 */
fun String.base64(): ByteArray = java.util.Base64.getDecoder().decode(this)
