package cn.qqck.kotlin.tools

import java.io.ByteArrayInputStream
import java.security.KeyFactory
import java.security.cert.CertificateFactory
import java.security.spec.PKCS8EncodedKeySpec

object KeyStore {
    /**
     * 将给定的PEM格式证书和私钥转换为KeyStore实例。
     *
     * @param cert PEM格式的证书字符串。
     * @param key PEM格式的私钥字符串。
     * @param alias KeyStore中条目的别名。
     * @param password KeyStore保护密钥条目的密码。
     * @param type 可选，KeyStore的类型，默认为"jks"。
     * @return 转换后的KeyStore实例。如果发生错误，返回null。
     */
    fun pem2ks(cert: String, key: String, alias: String, password: String, type: String = "jks"): java.security.KeyStore? = try {
        val j_keystore = java.security.KeyStore.getInstance(type)
        j_keystore.load(null, null)
        j_keystore.setKeyEntry(
            alias,
            KeyFactory.getInstance("RSA").generatePrivate(
                PKCS8EncodedKeySpec(
                    key.replace("-----BEGIN PRIVATE KEY-----", "")
                        .replace("-----END PRIVATE KEY-----", "")
                        .replace("\n", "")
                        .replace(" ", "")
                        .base64()
                )
            ),
            password.toCharArray(),
            CertificateFactory
                .getInstance("X.509")
                .generateCertificates(ByteArrayInputStream(cert.toByteArray()))
                .toTypedArray()
        )
        j_keystore
    } catch (e: Exception) {
        e.printStackTrace()
        null
    }
}
